import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
} from 'd3';

export const scatterPlot = (selection, props) => {
	const {
    title,
    xValue,
  	xAxisLabel,
  	yValue,
		circleRadius,
		yAxisLabel,
		margin,
    width,
    height,
    data,
    classColor
  } = props;
	
  

  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const plotWidth = innerWidth * 3/4;	
  const plotHeight = innerHeight;
  const iconSpace = innerWidth * 1/4;		
  
  
  //設定比例尺
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = selection.selectAll('.container').data([null]);
	const gEnter = g
  	.enter().append('g')
  		.attr('class', 'container');
  gEnter
    .merge(g)
    	.attr('transform', 
            `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.select('.y-axis');
  const	yAxisGEnter = gEnter
  	.append('g')
  		.attr('class', 'y-axis');
  
  yAxisG
  	.merge(yAxisGEnter)
 			.call(yAxis)
			.selectAll('.domain').remove();
  
  const yAxisLabelText = yAxisGEnter
		.append('text')
      .attr('class', 'axis-label')
      .attr('y', -70)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
  	.merge(yAxisG.select('.axis-label'))
  		.attr('x', -innerHeight / 2)
      .text(yAxisLabel);
  
  const xAxisG = g.select('.x-axis');
  const	xAxisGEnter = gEnter
  	.append('g')
  		.attr('class', 'x-axis');
  xAxisG
  	.merge(xAxisGEnter)
  		.attr('transform', `translate(0,${innerHeight})`)
 			.call(xAxis)
			.selectAll('.domain').remove();

  const xAxisLabelText = xAxisGEnter
		.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('fill', 'black')
  	.merge(xAxisG.select('.axis-label'))
  		.attr('x', innerWidth / 2)
      .text(xAxisLabel);
  
  //標示點
  const circles = g.merge(gEnter)
  	.selectAll('circle').data(data);
  circles
    .enter().append('circle')
  		.attr('cx', innerWidth / 2)
  		.attr('cy', innerHeight / 2)
  		.attr('r', 0)
  	.merge(circles)		//傳入一陣列 把所有資料合併為一陣列
  	.transition().duration(1500)
  	.delay((d, i) => i * 3)
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
  		.style('fill', d => classColor[d.class]);
  
  const classHeight = 20
  const classxAsis = 630
  //console.log( innerWidth / 2)
  
  // title
  gEnter.append('text')
  	.attr('class', 'title')
  	.attr('x', (innerWidth - margin.right) / 2 )
  	.attr('y', -classHeight)
  	.text(title);
  
  // icon
  gEnter.append('text')
  	.attr('class', 'sub-title')
  	.attr('x', classxAsis)
  	.attr('y',classHeight)
  	.text('Iris Classes');
  
  // Iris-setosa
   gEnter.append('circle')
  		.attr('cy', 50)
  		.attr('cx',classxAsis + circleRadius)
  		.attr('r', circleRadius)
  		.style('fill', classColor['Iris-setosa']);   
  gEnter.append('text')
  		.attr('y', 58)
  		.attr('x', classxAsis + 30)
  		.attr('font-size', '1.5rem')
  		.text('Iris-setosa');
  
  // Iris-versicolor
  gEnter.append('circle')
  		.attr('cy', 80)
  		.attr('cx', classxAsis + circleRadius)
  		.attr('r', circleRadius)
  		.style('fill', classColor['Iris-versicolor']);  
  gEnter.append('text')
  		.attr('y', 88)
  		.attr('x', classxAsis + 30)
  		.attr('font-size', '1.5rem')
  		.text('Iris-versicolor');
  
  // Iris-virginica
  gEnter.append('circle')
  		.attr('cy', 110)
  		.attr('cx', classxAsis + circleRadius)
  		.attr('r', circleRadius)
  		.style('fill', classColor['Iris-virginica']);
  gEnter.append('text')
  		.attr('y', 118)
  		.attr('x', classxAsis + 30)
  		.attr('font-size', '1.5rem')
  		.text('Iris-virginica');
  
  const axisHeight = 20 + innerHeight/2
  //console.log(axisHeight)
  
  // choose axis
  gEnter.append('text')
  	.attr('class', 'sub-title')
  	.attr('x', classxAsis)
  	.attr('y', 20 + innerHeight/2)
  	.text('Axis');
  gEnter.append('text')
    .attr('x', classxAsis)
    .attr('y', axisHeight + 30)
    .attr('font-size', '1.5em')
    .text('x-axis');
  gEnter.append('text')
    .attr('x', classxAsis)
  	.attr('y', axisHeight + 100)
    .att